* Table 1 -  column 'Actual trial';
* Proportion of patients lost to follow-up in 'Follow-up' subsection 
in Stage I section;
* WebTable 1 - column 'START';
 
options nofmterr nodate mprint notes ls=140  ;

proc format library = work ;
    value newlevel 0 ="<600"			
                   1=">=600"           
                   2=" <10,000"
                   3="10,000 - 100,000"
                   4="100,000 "
                   5="male"
                   6="female"         
                   7="Heterosexual"
                   8="Homo/bi-sexual"
                   9="Injection drug-use"
                   10="Other/unkown"                                 
		   		   11="2009-2010"
                   12="2011 - 2015"
		   			13="18-30"
		   			14="31-50"
		   			15=">51"
		   			
				   ;
run;



%macro subsets ;
	%let subsets = cd4_0_cat rna_0_cat sex  mode_new  year_0_cat age_0_cat;
	%let names = cd4 rna sex  mode  year age ;


* Descriptive statistics for included patients at baseline;
* To explore if there is any issues with the data ;

	data temp_bas;
	set cero;
	by id;
	if first.id;
	run; 	
	
	title "Distribution of CD4 count, year, age and RNA at baseline";
	proc univariate data=temp_bas;
	var cd4_0 year_0 age_0 rna_0;
	run;

		
* Descriptive statistics of CD4 and RNA in the month before the event occurred;
	data tmp_event;
	set cero (where=(&event=1));
	rename cd4_v=cd4_event rna_v=rna_event; 
	run;

	title "Distribution of CD4 count and RNA at time of death";
	proc univariate data=tmp_event;
	var cd4_event rna_event;
	title2 ""; 
	run;


* Descriptive statistics at cART initiation;

	data tmp ;
	set cero (where=(everhaart=1));
	by id;
	if first.id;
	run;

	title "Distribution of CD4 count and RNA at time of cART initiation";
	proc univariate data=tmp;
	var cd4_v rna_v month2;
	run;


    	data tmp0 ;
    	set cero ;
    	by id ;
    	if last.id ;
    	if event=. then month2 = month2 - 1; 
    	years = month2 / 12.0 ;
    	keep years everhaart event month2 ;
    	run;

    	proc means data = tmp0 noprint;
    	var years ;
    	output out = personyr_all (keep =  personyrs eligible )  sum=personyrs n = eligible ;
    	run;
	
	title "Total Person year of follow-up";
	proc print data=personyr_all;
	run;

    	proc means data=tmp0 noprint;
    	var month2 ;
    	output out=medianfup_all (keep = medianfup p25 p75) median=medianfup p25=p25 p75=p75;
    	run;

	title "Median [IQR] follow-up";
      	proc print data=medianfup_all;
	run;

	title "Number of indviduals ";

  	data all ;
  	run ;
	%do i = 1 %to 6;
    		%let subset_var = %scan(&subsets,%eval(&i),%str( ));
    		%let name = %scan(&names,%eval(&i),%str( ));

    		data tmp0 ;
    		set cero ;
    		by id ;
    		if last.id ;
    		if &event=. then month2 = month2 - 1; 
    		years = month2 / 12.0 ;
    		keep years &subset_var everhaart &event month2 ;
    		run;

    		proc sort data = tmp0 ;
    		by &subset_var ;
    		run;

    		proc means data = tmp0 noprint;
    		var years ;
    		by &subset_var ;
    		output out = personyr&name (keep = &subset_var  personyrs eligible )  sum=personyrs n = eligible ;
    		run;

    		proc means data=tmp0 noprint;
    		var month2 ;
    		by &subset_var ;
    		output out=medianfup&name (keep = &subset_var medianfup p25 p75) median=medianfup p25=p25 p75=p75;
    		run;

    		proc means data = tmp0 (where = (everhaart = 1)) noprint ;
    		var &subset_var ;
    		by &subset_var ;
    		output out = start&name (keep = &subset_var initiators) n = initiators ;
    		run;

    		proc freq data = tmp0 noprint; 
    		table &event / out = event&name (keep = &subset_var  &event count where = (&event = 1) rename = (count = events) );
    		by &subset_var ;
    		run;

   		data &name.stat ;
   		merge personyr&name medianfup&name start&name event&name ;
   		by &subset_var ;
   		length name $10. ;
   		name = "&name";
   		level = &subset_var ;
   		incidence=round(1000*(events/personyrs), 0.1) ; 
   		run;

    		data all ;
    		set all &name.stat ;
    		run;

	%end;


    data all;
    set all (where = (level > .));
    newlevel = _n_ - 1;         
    run;

    title "Descriptive statistics by baseline patients's characteristics"; 
    proc print data = all noobs label;
    var name newlevel  eligible personyrs initiators medianfup p25 p75 events  incidence;
    format newlevel newlevel. ;
    label name="Subset variable"
          newlevel="Variable level"
          personyrs="Person-years" 
          initiators="Initiators of cART during follow-up"
          medianfup="Median follow-up time, months"
          events="Number of  cases"
          incidence="Incidence rate, per 1000 person-years"
          ;
    
    run;
%mend ;

data cero;
set mylib.cero_start_aids_death;
 where month2<=60 and id not in (125,511,732,1679,1874,2296,3564,4122,4655);
year_0=year(rdate);
run;


options mprint notes bufno=10000 ;
title "Patients characteristics - ALL ";
footnote1 "Outcome: AIDS or death ";
ods rtf file="descr_start_aids_death_all.rtf";
%let event= event;
%subsets ;
ods rtf close ;


data cero;
set mylib.cero_start_aids_death;
	  where (( country_new=1 or country_new=2 or country_new=6 or substr(country_name,1,3)="Bra" ) and month2<=60 and  id not in (125,511,732,1679,1874,2296,3564,4122,4655));
year_0=year(rdate);
run;

options mprint notes bufno=10000 ;
title "Patients characteristics - High-income and Brazil ";
footnote1 "Outcome AIDS or death ";
ods rtf file="descr_start_aids_death_high_br.rtf";
%let event= event;
%subsets ;
ods rtf close ;



* How many people were lost to follow-up?;
data cens;
set mylib.cero_start_aids_death (keep=id month2 censy cd4_v);
where month2<=60;
by id;
if last.id;
run;

title "How many patients were lost to follow-up?";
proc freq data=cens;
tables censy;
run;

