* This SAS code computes the descriptive statistics in the first two paragraphs of the 
'Follow-up' subsection 'Stage 3' section;
* Analyses restricted to the four cohorts with lowest follow-up rate; 

* Identify which cohorts had less than 35% lost to follow-up);
data mydata;
set mylib.cero_hivc_aids_death_3_newvacs (keep=id month2 censy cohort_orig year_0);
where year_0>=2005 and year_0<=2013 and month2<60;
by id;
if last.id;
run;

proc sort data=mydata;
by cohort_orig;
run;

proc freq data=mydata;
by cohort_orig;
table censy/missing;
run;


  %include '/proj/sas_macros/gformula/Sept-2016/gformula_3.0.3.sas';

libname main '/proj/START/data/slodi/hivc_start';

options nofmterr nodate   nonumber ls=140  ;


* Second of two consecutive CD4<350;

%macro cutgrace_noaids(intcut=,intgrace=) ;

               
                 
                tgrace = month2 - &intgrace ;
               array dyncond{0:%eval(&timepoints-1)};

					  if ( sqrtcd4 < sqrt(&intcut) AND visit_cd4=1  AND sqrtcd4_l1 < sqrt(&intcut))=1 then do;

                               
                                                dyncond[month2]  = 1;
                                        end;
                                        else do;
                                                dyncond[month2] = 0;
                                        end;
                                       if month2 > 0 and  dyncond[month2 - 1] = 1 then dyncond[month2] = 1;
                                        if dyncond[month2] = 0 and s&&intvar&i [month2] = 1 then do;
                                                &&intvar&i = 0;
                                                s&&intvar&i[month2] = 0 ;
                                                &&intvar&i.._totinterv = &&intvar&i.._totinterv + 1;
                                                intervened = 1;
                                                intervenedk[month2] = 1;
                                                totinterv = totinterv + 1;
                                        end;
                                      
                                        if month2 ge &intgrace then do;
                                                if dyncond[tgrace] = 1 and s&&intvar&i[ month2] = 0 then do;
                                                        &&intvar&i = 1;
                                                        s&&intvar&i[month2] = 1 ;
                                                        &&intvar&i.._totinterv = &&intvar&i.._totinterv + 1;
                                                        intervened = 1;
                                                        intervenedk[month2] = 1;
                                                        totinterv = totinterv + 1;
                                                end;


                                        end;


%mend;


%macro my2mograce;

   if month2 = 2 then do;
        if everhaart = 0 then do;
            everhaart = 1 ;
            severhaart[month2] = 1;
            intervened = 1 ;
            everhaart_totinterv =everhaart_totinterv + 1;
            totinterv = totinterv + 1;
        end;
    end;

%mend;

* Include cohorts with smaller proportions of patients lost to follow-up :
SHCS, CoRIS, PISCIS;


data cero ;
set mylib.cero_hivc_aids_death_3_newvacs ;
where year_0>=2005 and year_0<=2013 and month2<60 and (  cohort=4 or cohort=8 or cohort=5 or cohort=9) ;
run;


%let nsamples =200;

%let interv1 =
intno=1,           intlabel='start within 2 months of baseline', nintvar=1,
intvar1=everhaart, inttype1=-1,  
	inttimes1= 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30
          31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 
		, intusermacro1=my2mograce;


%let interv2 =
intno=2,           intlabel='first cd4<350, 2 months', nintvar=1,
intvar1=everhaart, inttype1=-1,  
	inttimes1= 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30
          31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59
		 , intusermacro1=cutgrace_noaids(intcut=351,intgrace=2);


%let timenow=%sysfunc(time(), time.);
%let datenow=%sysfunc(date(), date9.);
%put Initiating Program;
%put Time is &datenow / &timenow ;
%put Outcome: AIDS or death - 2 month intervals - patients linked to care;
%put ; 

 
%gformula(
data=cero,
id=id,
time=month2,  timeptype=conspl, timeknots=  3 8 19 34 53,       timepoints=60,
outc=event, 
outctype=binsurv, 
censlost=censor,  
numint=2,
fixedcov=  sex origin_cat_1 origin_cat_2 origin_cat_3 race_new_1 race_new_2 cd4_0_cat rna_0_cat_1 rna_0_cat_2     
	mode_new_1 mode_new_2 mode_new_3 year_0_cat age_0_cat_1 age_0_cat_2 ,
ncov=3, 
cov1=lnrna,     cov1otype=4, cov1ptype=lag1bin, 
cov1randomvisitp = visit_rna, cov1visitpmaxgap = 12 , cov1visitpcount = ts_rna_l1 , 

cov2=sqrtcd4,     cov2otype=3, cov2ptype=lag1bin, 
cov2randomvisitp = visit_cd4,   cov2visitpcount = ts_cd4_l1 , cov2visitpmaxgap = 12, 

cov3=everhaart, cov3otype=2, cov3ptype=tsswitch1, 
refint=1,
print_stats=0,
intervname=interv,
 savelib=work,
simuldata=,
rungraphs = 0,
runnc = 0 ,
seed=3,
nsamples=&nsamples,
minimalistic = yes ,
usespline = 0 ,
printlogstats = 0
);


